import { select, csv, json, geoPath, geoMercator, geoNaturalEarth1,zoom,event, scaleOrdinal
        ,schemeGreens,scaleLinear,map} from 'd3';
import { colorLegend } from './colorLegend';
import { loadAndProcessData } from './loadAndProcessData';
import { dropdownMenu } from './dropdownMenu';
import { onReady } from './loadPage';

const svg = select('svg');

const width = document.body.clientWidth;
const height = document.body.clientHeight;
const scale = 7;
const widthscale = -640*(scale-1);
const heightscale = -140*(scale-1);


let xColumn;

const onXColumnClicked = column => {
  xColumn = column;
  render3();
};

const render2 = () => {
  
    xColumn = Object.keys(features[0].properties)[9];
  	console.log(xColumn);
  	onXColumnClicked(xColumn);
  	onReady();
}

const render3 = () => {
  
  	select('#x-menu')
    .call(dropdownMenu, {
      options: Object.keys(features[0].properties).slice(9, Object.keys(features[0].properties).length),
      onOptionClicked: onXColumnClicked,
      selectedOption: xColumn
    });
  	render();
}

const zoomG = svg
    .attr('width', width)
    .attr('height', height)
  .append('g');

const iran = zoomG.append('g')
	.attr('transform', `translate(${widthscale},${heightscale}), scale(${scale})`);

const colorLegendG = svg.append('g')
    .attr('transform', `translate(40,40)`);

const projection = geoMercator();
const pathGenerator = geoPath().projection(projection);


svg.call(zoom().on('zoom', () => {
  zoomG.attr('transform', event.transform);
}));

const recti = svg.append('rect')
  .attr('x', 0).attr('y', 0).attr('width', width)
	.attr('height', height).attr('fill','white').attr('rx','10');


const colorScale = scaleLinear();
const colorScale2 = scaleOrdinal();
let colorValue = d => Math.log(+d.properties[xColumn])*10;
let realColorValue = d => +d.properties[xColumn];



let features;

loadAndProcessData().then(data => {
    features = data.features;
    console.log(Object.keys(features[0].properties).slice(9, Object.keys(features[0].properties).length));
  	render2();
  });

function getRandomColor() {
  var letters = '0123456789ABCDEF';
  var color = '#';
  for (var i = 0; i < 6; i++) {
    color += letters[Math.floor(Math.random() * 16)];
  }
  return color;
}



const render = () => {
  				
  				let colorz = features.map(colorValue);
  				let colorz2 = colorz.sort((a,b) => a - b).reverse();
  				let colorz3 = getRandomColor();
  
  				colorScale
          	.domain([colorz2[colorz2.length-1],colorz2[0]])
  					.range(["white",colorz3]);
					
  
  				colorScale2
            .domain(['Most Value','Least Value'])
  					.range([colorz3,'white']);

          colorLegendG.call(colorLegend, {
            colorScale: colorScale2,
            circleRadius: 8,
            spacing: 20,
            textOffset: 12,
            backgroundRectWidth: 140
          });
  
					//console.log(colorScale.domain());

          const iran2 = iran.selectAll('path').data(features);
  				iran2.selectAll("title").remove();
  					
  				  iran2
            .enter().append('path')
            .attr('class', 'city')
            .attr('d',pathGenerator)
  					.attr('fill', d => colorScale(colorValue(d)))
  					.merge(iran2)
            .append('title')
  					.text(d => d.properties.NAME_1 + `\n value of ${xColumn}: ` + realColorValue(d));
  					//.transition().duration(1500).delay((d, i) => i * 10)
  					//.attr('fill', d => colorScale(colorValue(d)));
  
  					iran2
            .transition().duration(1000).delay((d, i) => i * 10)
  					.attr('fill', "white")
						.transition().duration(1500).delay((d, i) => i * 10)
  					.attr('fill', d => colorScale(colorValue(d)));

  					// iran2
  					// .append('title')
  					// .text(d => d.properties.NAME_1 + `\n value of ${xColumn}: ` + realColorValue(d));
  					
  				  
  				iran2.exit().remove();
  
  
       };


